
# Type: uriorcurie


a URI or a CURIE

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Uriorcurie](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Uriorcurie)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **URIorCURIE** |
| Representation | | str |
